@@ -662,7 +662,6 @@ itertools = _LazyModule.load('itertools', 'itertools')
 # amalgamated os
 re = _LazyModule.load('re', 're')
 socket = _LazyModule.load('socket', 'socket')
-string = _LazyModule.load('string', 'string')
 # amalgamated sys
 # amalgamated xonsh.lazyasd
 # amalgamated xonsh.tools
@@ -702,7 +701,7 @@ class PromptFormatter:
     def _format_prompt(self, template=DEFAULT_PROMPT):
         template = template() if callable(template) else template
         toks = []
-        for literal, field, spec, conv in _FORMATTER.parse(template):
+        for literal, field, spec, conv in xt.FORMATTER.parse(template):
             toks.append(literal)
             entry = self._format_field(field, spec, conv)
             if entry is not None:
@@ -756,11 +755,6 @@ def PROMPT_FIELDS():
     )
 
 
-@xl.lazyobject
-def _FORMATTER():
-    return string.Formatter()
-
-
 def default_prompt():
     """Creates a new instance of the default prompt."""
     if xp.ON_CYGWIN or xp.ON_MSYS:
@@ -853,7 +847,7 @@ def is_template_string(template, PROMPT_FIELDS=None):
     """Returns whether or not the string is a valid template."""
     template = template() if callable(template) else template
     try:
-        included_names = set(i[1] for i in _FORMATTER.parse(template))
+        included_names = set(i[1] for i in xt.FORMATTER.parse(template))
     except ValueError:
         return False
     included_names.discard(None)
@@ -875,9 +869,9 @@ def _format_value(val, spec, conv):
     """
     if val is None:
         return ""
-    val = _FORMATTER.convert_field(val, conv)
+    val = xt.FORMATTER.convert_field(val, conv)
     if spec:
-        val = _FORMATTER.format(spec, val)
+        val = xt.FORMATTER.format(spec, val)
     if not isinstance(val, str):
         val = str(val)
     return val
